//==============================================================================
//
//  This file is part of GNSSTk, the ARL:UT GNSS Toolkit.
//
//  The GNSSTk is free software; you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published
//  by the Free Software Foundation; either version 3.0 of the License, or
//  any later version.
//
//  The GNSSTk is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with GNSSTk; if not, write to the Free Software Foundation,
//  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
//
//  This software was developed by Applied Research Laboratories at the
//  University of Texas at Austin.
//  Copyright 2004-2022, The Board of Regents of The University of Texas System
//
//==============================================================================

//==============================================================================
//
//  This software was developed by Applied Research Laboratories at the
//  University of Texas at Austin, under contract to an agency or agencies
//  within the U.S. Department of Defense. The U.S. Government retains all
//  rights to use, duplicate, distribute, disclose, or release this software.
//
//  Pursuant to DoD Directive 523024
//
//  DISTRIBUTION STATEMENT A: This software has been approved for public
//                            release, distribution is unlimited.
//
//==============================================================================

#include <iostream>
#include <cmath>

#include "convhelp.hpp"
#include "GPSEllipsoid.hpp"

#include "TestUtil.hpp"

int main()
{
   TUDEF("convhelp", "");
   double eps = 1e-12;

   gnsstk::WGS84Ellipsoid wem;
   gnsstk::GPSEllipsoid gem;

   testFramework.changeSourceMethod("WGS84Ellipsoid cycles2meters");
   TUASSERTFEPS(gnsstk::cycles2meters(100000., 400000.,wem), 74948114.5, eps);
   TUASSERTFEPS(gnsstk::cycles2meters(0,5,wem), 0, eps);
   TUASSERTFEPS(gnsstk::cycles2meters(-100000.,400000.,wem), -74948114.5, eps);

   testFramework.changeSourceMethod("GPSEllipsoid cycles2meters");
   TUASSERTFEPS(gnsstk::cycles2meters(100000.,400000.,gem), 74948114.5, eps);
   TUASSERTFEPS(gnsstk::cycles2meters(0,5,gem), 0, eps);
   TUASSERTFEPS(gnsstk::cycles2meters(-100000.,400000.,gem), -74948114.5, eps);

   testFramework.changeSourceMethod("WGS84Ellipsoid meters2cycles");
   TUASSERTFEPS(gnsstk::meters2cycles(74948114.5,400000.,wem), 100000, eps);
   TUASSERTFEPS(gnsstk::meters2cycles(0,5,wem), 0, eps);
   TUASSERTFEPS(gnsstk::meters2cycles(-74948114.5,400000.,wem), -100000, eps);

   testFramework.changeSourceMethod("GPSEllipsoid meters2cycles");
   TUASSERTFEPS(gnsstk::meters2cycles(74948114.5,400000.,gem), 100000, eps);
   TUASSERTFEPS(gnsstk::meters2cycles(0,5,gem), 0, eps);
   TUASSERTFEPS(gnsstk::meters2cycles(-74948114.5,400000.,gem), -100000, eps);

   testFramework.changeSourceMethod("cel2far");
   TUASSERTFEPS(gnsstk::cel2far(100),   212, eps);
   TUASSERTFEPS(gnsstk::cel2far(0),      32, eps);
   TUASSERTFEPS(gnsstk::cel2far(-100), -148, eps);

   testFramework.changeSourceMethod("far2cel");
   TUASSERTFEPS(gnsstk::far2cel(212),   100, eps);
   TUASSERTFEPS(gnsstk::far2cel(32),      0, eps);
   TUASSERTFEPS(gnsstk::far2cel(-148), -100, eps);

   testFramework.changeSourceMethod("mb2hg");
   TUASSERTFEPS(gnsstk::mb2hg(100), 2.9529987508079487, eps);
   TUASSERTFEPS(gnsstk::mb2hg(0), 0, eps);
   TUASSERTFEPS(gnsstk::mb2hg(-100), -2.9529987508079487, eps);

   testFramework.changeSourceMethod("hg2mb");
   TUASSERTFEPS(gnsstk::hg2mb(2.9529987508079487), 100, eps);
   TUASSERTFEPS(gnsstk::hg2mb(0), 0, eps);
   TUASSERTFEPS(gnsstk::hg2mb(-2.9529987508079487), -100, eps);

   std::cout << "Total Failures for " << __FILE__ << ": " << testFramework.countFails() << std::endl;

   return testFramework.countFails();
}
